@@ -3,7 +3,7 @@
  * DbPsql.cc
  *   Class to handle postgresql database.
  *
- * $Id: DbPsql.cc,v 1.20 2002/04/08 07:11:01 benoit Exp $
+ * $Id: DbPsql.cc,v 1.21 2003/04/24 04:44:56 benoit Exp $
  *
  * Copyright (c) 2000-2001 Remi Lefebvre <remi@dhis.net>
  * Copyright (c) 2000 Luca Filipozzi <lfilipoz@dhis.net>
@@ -41,7 +41,7 @@ DbPsql::DbPsql(Logger *log, const char *dbname, const char *dbuser,
     
     conninfo << "dbname=" << dbname
              << " user=" << dbuser
-             << " password=" << dbpass << ends;
+             << " password=" << dbpass << std::ends;
     
     if ((pg = new PgDatabase (conninfo.str().c_str())) == NULL)
     {
@@ -88,7 +88,7 @@ int DbPsql::addUserAccount (UserAccount *account)
                 << " hostStatus='" << OFFLINE << "',"
                 << " fqdn='" << account->fqdn << "',"
                 << " ipAddress='" << account->ipAddress << "'"
-                << " WHERE userAccountId=" << id << ends;
+                << " WHERE userAccountId=" << id << std::ends;
              
     // fill database
     if (pg->ExecCommandOk (updateQuery.str().c_str()) == false)
@@ -96,9 +96,9 @@ int DbPsql::addUserAccount (UserAccount *account)
         ostringstream msg;
         
         msg << "DbPsql::addUserAccount(): pg->ExecCommandOk (" 
-            << updateQuery.str().c_str() << ") " << pg->ErrorMessage() << ends;
+            << updateQuery.str().c_str() << ") " << pg->ErrorMessage() << std::ends;
 
-        log->debug(msg.str().c_str());
+        log->debug("%s", msg.str().c_str());
         delUserAccount(id);
         throw DbError(msg.str().c_str());
     }
@@ -117,7 +117,7 @@ int DbPsql::allocateUserAccountId ()
     query << "SELECT useraccountid FROM useraccounts u1 WHERE "
           << "NOT EXISTS(SELECT * FROM useraccounts u2 WHERE "
           << "u1.useraccountid+1=u2.useraccountid) "
-          << "AND userAccountId>=1000 ORDER BY userAccountId LIMIT 1" << ends;
+          << "AND userAccountId>=1000 ORDER BY userAccountId LIMIT 1" << std::ends;
 
     if (pg->ExecTuplesOk(query.str().c_str()) == false)
     {
@@ -148,7 +148,7 @@ int DbPsql::allocateUserAccountId ()
 
     // add new accountid into database
     insertQuery << "INSERT into userAccounts (userAccountId) values ("
-                << id << ")" << ends;
+                << id << ")" << std::ends;
 
     if (pg->ExecCommandOk (insertQuery.str().c_str()) == false)
     {
@@ -165,7 +165,7 @@ int DbPsql::allocateUserAccountId ()
 void DbPsql::delUserAccount (int id)
 {
     ostringstream query;
-    query << "DELETE FROM userAccounts WHERE userAccountId=" << id << ends;
+    query << "DELETE FROM userAccounts WHERE userAccountId=" << id << std::ends;
     
     if (pg->ExecCommandOk(query.str().c_str()) == false)
     {
@@ -178,7 +178,7 @@ bool DbPsql::accountIdExists(int id)
     ostringstream request;
 
     request << "SELECT * from userAccounts where userAccountId=" 
-            << id << ends;
+            << id << std::ends;
 
 
     if (!pg->ExecTuplesOk (request.str().c_str()))
@@ -202,7 +202,7 @@ int DbPsql::getNbOfDnsRecords(int accountId, DnsRecordType type)
     // registered
     
     query << "SELECT * FROM dnsrecords WHERE type='" << type << "' AND "
-          << "userAccountId='" << accountId << "'" << ends;
+          << "userAccountId='" << accountId << "'" << std::ends;
 
     if (pg->ExecTuplesOk (query.str().c_str()) == false)
     {
@@ -228,7 +228,7 @@ int DbPsql::pruneActiveAccount(void (*func)(int, unsigned long, time_t))
 
     query << "SELECT userAccountId, ipAddress, date_part('epoch', lastAccess) "
           << "FROM userAccounts WHERE ipAddress <> '169.254.0.0' AND "
-          << "hostStatus != 3" << ends;
+          << "hostStatus != 3" << std::ends;
     // FIXME: FIXME: FIXME: this should be a define for the static status 
 
     // If there are any tuples, the Fqdn is not valid.
@@ -273,7 +273,7 @@ void DbPsql::modUserAccount(int id, char *field, char *value)
     ostringstream query;
 
     query << "UPDATE userAccounts SET " << field << "='" << value << "' "
-          << "WHERE userAccountId='" << id << "'" << ends;
+          << "WHERE userAccountId='" << id << "'" << std::ends;
     
     if (pg->ExecCommandOk(query.str().c_str()) == false)
     {
@@ -286,7 +286,7 @@ void DbPsql::modUserAccount(int id, char *field, int value)
     ostringstream query;
 
     query << "UPDATE userAccounts SET " << field << "='" << value << "' "
-          << "WHERE userAccountId='" << id << "'" << ends;
+          << "WHERE userAccountId='" << id << "'" << std::ends;
     
     if (pg->ExecCommandOk(query.str().c_str()) == false)
     {
@@ -319,7 +319,7 @@ void DbPsql::addDnsRecord(int accountId, const char *dname,
     case CNAME:
         if (nbDnsRecords >= 5)
         {
-            cout << "Too many CNAMEs" << endl;
+            std::cout << "Too many CNAMEs" << std::endl;
             log->debug("DbPsql::addDnsRecord (): Nb of CNAME allowed is 5");
             throw DdtException("DbPsql::addDnsRecord (): Nb of CNAME "
                                "allowed is 5");
@@ -328,7 +328,7 @@ void DbPsql::addDnsRecord(int accountId, const char *dname,
         // check if the requested record is available
         query << "SELECT * FROM userAccounts u, dnsRecords d WHERE "
               << "u.fqdn='" << dname << "' OR d.dname='" << dname
-              << "' AND d.type=" << CNAME << ends;
+              << "' AND d.type=" << CNAME << std::ends;
 
         if (pg->ExecTuplesOk(query.str().c_str()) == false)
         {
@@ -347,7 +347,7 @@ void DbPsql::addDnsRecord(int accountId, const char *dname,
     case MX:
         if (nbDnsRecords >= 2)
         {
-            cout << "Too many MXs" << endl;
+            std::cout << "Too many MXs" << std::endl;
             log->debug ("DbPsql::addDnsRecord(): Nb of MX allowed is 2");
             throw DdtException("DbPsql::addDnsRecord(): Nb of MX "
                                "allowed is 2");
@@ -363,7 +363,7 @@ void DbPsql::addDnsRecord(int accountId, const char *dname,
     // update the database
     insert << "INSERT INTO dnsRecords (useraccountid, dname, type, data) "
            << "VALUES ('" << accountId << "', '" << dname << "', '"
-           << type << "', '" << data << "')" << ends;
+           << type << "', '" << data << "')" << std::ends;
     
     if (pg->ExecCommandOk(insert.str().c_str()) == false)
     {
@@ -389,7 +389,7 @@ void DbPsql::delDnsRecords(int id)
     };
 
     query << "SELECT * FROM dnsRecords WHERE userAccountId='"
-          << id << "'" << ends;
+          << id << "'" << std::ends;
 
     if (pg->ExecTuplesOk(query.str().c_str()) == false)
     {
@@ -400,8 +400,8 @@ void DbPsql::delDnsRecords(int id)
     int nbTuples = pg->Tuples();
     recs r[nbTuples];
     str << "DbPsql::delDnsRecords (): nb of dns records for host " << id
-        << " = " << nbTuples << ends;
-    log->debug(str.str().c_str());
+        << " = " << nbTuples << std::ends;
+    log->debug("%s", str.str().c_str());
 
 
     /* we need to first build a list and then loop through it because
@@ -431,16 +431,16 @@ void DbPsql::delDnsRecord(int id, const char *dname, DnsRecordType type,
     ostringstream str;
 
     str << "dname: " << dname << " data: " << data << " type: "
-        << type << ends;
+        << type << std::ends;
 
-    log->debug(str.str().c_str());
+    log->debug("%s", str.str().c_str());
 
     // update the database
     query << "DELETE FROM dnsRecords WHERE "
           << "userAccountId='" << id << "' "
           << "AND dname='" << dname << "' "
           << "AND type='" << type << "' "
-          << "AND data='" << data << "'" << ends;
+          << "AND data='" << data << "'" << std::ends;
 
     if (pg->ExecCommandOk (query.str().c_str()) == false)
     {
@@ -453,12 +453,12 @@ void DbPsql::delDnsRecord(int id, const char *dname, DnsRecordType type,
 }
 
 /* do we need such a function? its darn ugly. */
-void DbPsql::listDnsRecords(int id, vector<DnsRecord> &dnsRecordList)
+void DbPsql::listDnsRecords(int id, std::vector<DnsRecord> &dnsRecordList)
 {
     ostringstream query;
 
     query << "SELECT * FROM dnsRecords WHERE userAccountId='"
-          << id << "'" << ends;
+          << id << "'" << std::ends;
 
     if (pg->ExecTuplesOk(query.str().c_str()) == false)
     {
@@ -468,8 +468,8 @@ void DbPsql::listDnsRecords(int id, vector<DnsRecord> &dnsRecordList)
     ostringstream str;
     int nbTuples = pg->Tuples();
     str << "DbPsql::delDnsRecords (): nb of dns records for host " << id
-        << " = " << nbTuples << ends;
-    log->debug(str.str().c_str());
+        << " = " << nbTuples << std::ends;
+    log->debug("%s", str.str().c_str());
 
 
     DnsRecord record;
@@ -493,7 +493,7 @@ bool DbPsql::fetchAccountInfo (int id, UserAccount *account)
 
     query << "SELECT userAccountId, adminPassword, updatePassword, "
           << "contactName, contactEmail, arch, os, hostStatus, fqdn, "
-          << "ipAddress from userAccounts WHERE userAccountId=" << id << ends;
+          << "ipAddress from userAccounts WHERE userAccountId=" << id << std::ends;
 
     if (!pg->ExecTuplesOk (query.str().c_str()) || pg->Tuples() != 1)
     {
@@ -539,7 +539,7 @@ int DbPsql::findUserAccountIdFromFqdn(const char *fqdn)
 
     ostringstream query;
     query << "SELECT userAccountId FROM userAccounts WHERE fqdn='"
-          << fqdn << "'" << ends;
+          << fqdn << "'" << std::ends;
     
     if (pg->ExecTuplesOk(query.str().c_str()) == false)
     {
@@ -561,7 +561,7 @@ unsigned long DbPsql::fetchAcctAddr(int id)
     char addr[16];
 
     query << "SELECT ipAddress from userAccounts WHERE userAccountId="
-          << id << ends;
+          << id << std::ends;
     
     if(pg->ExecTuplesOk(query.str().c_str()) == false)
     {
