@@ -1,6 +1,6 @@
 /* hey emacs! -*- Mode: C++; c-file-style: "stroustrup"; indent-tabs-mode: nil -*- */
 /*
- * $Id: DdtMD.cc,v 1.2 2002/04/08 07:11:28 benoit Exp $
+ * $Id: DdtMD.cc,v 1.3 2002/06/26 03:43:42 benoit Exp $
  *
  * Copyright (c) 2001 Benoit Joly <benoit@dhis.net>
  *
@@ -53,7 +53,7 @@ int DdtMD::doFinal(unsigned char *buf, int length)
 {
     gcry_md_final(mdHandle);
 
-    byte *md = gcry_md_read(mdHandle, algo);
+    unsigned char *md = gcry_md_read(mdHandle, algo);
 
     int mdLength = getAlgoDigestLength(algo);
 
